HeaderName

Enum HeaderName 

#[non_exhaustive]
#[repr(u8)]
pub enum HeaderName<'x> {
Show 141 variants Other(Cow<'x, str>), Subject = 0, From = 1, To = 2, Cc = 3, Date = 4, Bcc = 5, ReplyTo = 6, Sender = 7, Comments = 8, InReplyTo = 9, Keywords = 10, Received = 11, MessageId = 12, References = 13, ReturnPath = 14, MimeVersion = 15, ContentDescription = 16, ContentId = 17, ContentLanguage = 18, ContentLocation = 19, ContentTransferEncoding = 20, ContentType = 21, ContentDisposition = 22, ResentTo = 23, ResentFrom = 24, ResentBcc = 25, ResentCc = 26, ResentSender = 27, ResentDate = 28, ResentMessageId = 29, ListArchive = 30, ListHelp = 31, ListId = 32, ListOwner = 33, ListPost = 34, ListSubscribe = 35, ListUnsubscribe = 36, DkimSignature = 38, ArcAuthenticationResults = 39, ArcMessageSignature = 40, ArcSeal = 41, Dkim2Signature = 42, MessageInstance = 43, AcceptLanguage = 44, AlternateRecipient = 45, ArchivedAt = 46, AuthenticationResults = 47, AutoSubmitted = 48, Autoforwarded = 49, Autosubmitted = 50, ContentAlternative = 51, ContentDuration = 52, ContentFeatures = 53, ContentMd5 = 54, ContentTranslationType = 55, Conversion = 56, ConversionWithLoss = 57, DlExpansionHistory = 58, DeferredDelivery = 59, DeliveryDate = 60, DiscardedX400IpmsExtensions = 61, DiscardedX400MtsExtensions = 62, DiscloseRecipients = 63, DispositionNotificationOptions = 64, DispositionNotificationTo = 65, DowngradedFinalRecipient = 66, DowngradedInReplyTo = 67, DowngradedMessageId = 68, DowngradedOriginalRecipient = 69, DowngradedReferences = 70, Encoding = 71, Expires = 72, GenerateDeliveryReport = 73, HpOuter = 74, Importance = 75, IncompleteCopy = 76, Language = 77, LatestDeliveryTime = 78, ListUnsubscribePost = 79, MessageContext = 80, MessageType = 81, MmhsExemptedAddress = 82, MmhsExtendedAuthorisationInfo = 83, MmhsSubjectIndicatorCodes = 84, MmhsHandlingInstructions = 85, MmhsMessageInstructions = 86, MmhsCodressMessageIndicator = 87, MmhsOriginatorReference = 88, MmhsPrimaryPrecedence = 89, MmhsCopyPrecedence = 90, MmhsMessageType = 91, MmhsOtherRecipientsIndicatorTo = 92, MmhsOtherRecipientsIndicatorCc = 93, MmhsAcp127MessageIdentifier = 94, MmhsOriginatorPlad = 95, MtPriority = 96, Organization = 97, OriginalEncodedInformationTypes = 98, OriginalFrom = 99, OriginalMessageId = 100, OriginalRecipient = 101, OriginatorReturnAddress = 102, OriginalSubject = 103, PicsLabel = 104, PreventNonDeliveryReport = 105, Priority = 106, ReceivedSpf = 107, ReplyBy = 108, RequireRecipientValidSince = 109, Sensitivity = 110, Solicitation = 111, Supersedes = 112, TlsReportDomain = 113, TlsReportSubmitter = 114, TlsRequired = 115, VbrInfo = 116, X400ContentIdentifier = 117, X400ContentReturn = 118, X400ContentType = 119, X400MtsIdentifier = 120, X400Originator = 121, X400Received = 122, X400Recipients = 123, X400Trace = 124, ApparentlyTo = 125, Author = 126, CfblAddress = 127, CfblFeedbackId = 128, DeliveredTo = 129, EdiintFeatures = 130, EesstVersion = 131, ErrorsTo = 132, Face = 133, FormSub = 134, JabberId = 135, MmhsAuthorizingUsers = 136, Privicon = 137, SioLabel = 138, SioLabelHistory = 139, WrongRecipient = 140,
}
A header field

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Other(Cow<'x, str>)



Subject = 0



From = 1



To = 2



Cc = 3



Date = 4



Bcc = 5



ReplyTo = 6



Sender = 7



Comments = 8



InReplyTo = 9



Keywords = 10



Received = 11



MessageId = 12



References = 13



ReturnPath = 14



MimeVersion = 15



ContentDescription = 16



ContentId = 17



ContentLanguage = 18



ContentLocation = 19



ContentTransferEncoding = 20



ContentType = 21



ContentDisposition = 22



ResentTo = 23



ResentFrom = 24



ResentBcc = 25



ResentCc = 26



ResentSender = 27



ResentDate = 28



ResentMessageId = 29



ListArchive = 30



ListHelp = 31



ListId = 32



ListOwner = 33



ListPost = 34



ListSubscribe = 35



ListUnsubscribe = 36



DkimSignature = 38



ArcAuthenticationResults = 39



ArcMessageSignature = 40



ArcSeal = 41



Dkim2Signature = 42



MessageInstance = 43



AcceptLanguage = 44



AlternateRecipient = 45



ArchivedAt = 46



AuthenticationResults = 47



AutoSubmitted = 48



Autoforwarded = 49



Autosubmitted = 50



ContentAlternative = 51



ContentDuration = 52



ContentFeatures = 53



ContentMd5 = 54



ContentTranslationType = 55



Conversion = 56



ConversionWithLoss = 57



DlExpansionHistory = 58



DeferredDelivery = 59



DeliveryDate = 60



DiscardedX400IpmsExtensions = 61



DiscardedX400MtsExtensions = 62



DiscloseRecipients = 63



DispositionNotificationOptions = 64



DispositionNotificationTo = 65



DowngradedFinalRecipient = 66



DowngradedInReplyTo = 67



DowngradedMessageId = 68



DowngradedOriginalRecipient = 69



DowngradedReferences = 70



Encoding = 71



Expires = 72



GenerateDeliveryReport = 73



HpOuter = 74



Importance = 75



IncompleteCopy = 76



Language = 77



LatestDeliveryTime = 78



ListUnsubscribePost = 79



MessageContext = 80



MessageType = 81



MmhsExemptedAddress = 82



MmhsExtendedAuthorisationInfo = 83



MmhsSubjectIndicatorCodes = 84



MmhsHandlingInstructions = 85



MmhsMessageInstructions = 86



MmhsCodressMessageIndicator = 87



MmhsOriginatorReference = 88



MmhsPrimaryPrecedence = 89



MmhsCopyPrecedence = 90



MmhsMessageType = 91



MmhsOtherRecipientsIndicatorTo = 92



MmhsOtherRecipientsIndicatorCc = 93



MmhsAcp127MessageIdentifier = 94



MmhsOriginatorPlad = 95



MtPriority = 96



Organization = 97



OriginalEncodedInformationTypes = 98



OriginalFrom = 99



OriginalMessageId = 100



OriginalRecipient = 101



OriginatorReturnAddress = 102



OriginalSubject = 103



PicsLabel = 104



PreventNonDeliveryReport = 105



Priority = 106



ReceivedSpf = 107



ReplyBy = 108



RequireRecipientValidSince = 109



Sensitivity = 110



Solicitation = 111



Supersedes = 112



TlsReportDomain = 113



TlsReportSubmitter = 114



TlsRequired = 115



VbrInfo = 116



X400ContentIdentifier = 117



X400ContentReturn = 118



X400ContentType = 119



X400MtsIdentifier = 120



X400Originator = 121



X400Received = 122



X400Recipients = 123



X400Trace = 124



ApparentlyTo = 125



Author = 126



CfblAddress = 127



CfblFeedbackId = 128



DeliveredTo = 129



EdiintFeatures = 130



EesstVersion = 131



ErrorsTo = 132



Face = 133



FormSub = 134



JabberId = 135



MmhsAuthorizingUsers = 136



Privicon = 137



SioLabel = 138



SioLabelHistory = 139



WrongRecipient = 140

Implementations

Source

impl HeaderName<'_>

pub fn into_string(self) -> String

pub fn as_str(&self) -> &str

pub fn len(&self) -> usize

pub fn is_structured(&self) -> bool

Returns true if the default parser yields a structured value for this header.

pub fn is_mime_header(&self) -> bool

Returns true if it is a MIME header.

pub fn is_other(&self) -> bool

Returns true if it is an Other header name

pub fn is_empty(&self) -> bool

Source

impl<'x> HeaderName<'x>

pub fn parse(data: impl Into<Cow<'x, str>>) -> Option<HeaderName<'x>>

Parse a header name

Source

impl HeaderName<'_>

pub fn as_static_str(&self) -> &'static str

pub fn id(&self) -> u8

pub fn to_owned(&self) -> HeaderName<'static>

pub fn into_owned(self) -> HeaderName<'static>