MessageParser

Struct MessageParser 

pub struct MessageParser { /* private fields */ }
RFC5322/RFC822 message parser.

Implementations

Source

impl MessageParser

pub fn new() -> Self

Create a new builder for a message parser using the default settings.

The default settings are:

  • IANA-registered headers defined in HeaderName are parsed with their corresponding parser.
  • Other headers (HeaderName::Other) are parsed as raw.
pub fn with_mime_headers(self) -> Self

Parse all MIME headers:

  • Content-Type
  • Content-Disposition
  • Content-Id
  • Content-Description
  • Content-Location
  • Content-Transfer-Encoding

Adding these MIME headers is required in order to parse message bodies.

pub fn with_date_headers(self) -> Self

Parse all Date headers:

  • Date
  • Resent-Date
pub fn with_address_headers(self) -> Self

Parse all address headers:

  • From
  • Sender
  • Reply-To
  • To
  • Cc
  • Bcc
  • Resent-From
  • Resent-Sender
  • Resent-To
  • Resent-Cc
  • Resent-Bcc
pub fn with_message_ids(self) -> Self

Parse all ID headers:

  • Message-Id
  • In-Reply-To
  • References
  • Resent-Message-Id
pub fn with_minimal_headers(self) -> Self

Parse all MIME headers plus:

  • Date
  • From
  • Reply-To
  • To
  • Cc
  • Bcc
pub fn without_header(self, header: impl Into<HeaderName<'static>>) -> Self

Remove a custom header parser.

pub fn header_text(self, header: impl Into<HeaderName<'static>>) -> Self

Parse a header as text decoding RFC 2047 encoded words.

pub fn header_date(self, header: impl Into<HeaderName<'static>>) -> Self

Parse a header as a RFC 5322 date.

pub fn header_address(self, header: impl Into<HeaderName<'static>>) -> Self

Parse a header as an address.

pub fn header_id(self, header: impl Into<HeaderName<'static>>) -> Self

Parse a header as an ID.

pub fn header_content_type(self, header: impl Into<HeaderName<'static>>) -> Self

Parse a header as a MIME Content-Type or Content-Disposition type.

pub fn header_comma_separated( self, header: impl Into<HeaderName<'static>>, ) -> Self

Parse a header as a comma-separated list of values.

pub fn header_received(self, header: impl Into<HeaderName<'static>>) -> Self

Parse a header as a received header.

pub fn header_raw(self, header: impl Into<HeaderName<'static>>) -> Self

Parse a header as a raw string, no RFC 2047 decoding is done.

pub fn ignore_header(self, header: impl Into<HeaderName<'static>>) -> Self

Ignore and skip parsing a header.

pub fn default_header_text(self) -> Self

Parse all other headers as text decoding RFC 2047 encoded words.

pub fn default_header_raw(self) -> Self

Parse all other headers as raw strings, no RFC 2047 decoding is done.

pub fn default_header_ignore(self) -> Self

Ignore and skip parsing all other headers.

Source

impl MessageParser

pub fn parse<'x>( &self, raw_message: &'x (impl AsRef<[u8]> + ?Sized), ) -> Option<Message<'x>>

Parses a byte slice containing the RFC5322 raw message and returns a Message struct.

This function never panics, a best-effort is made to parse the message and if no headers are found None is returned.

pub fn parse_headers<'x>( &self, raw_message: &'x (impl AsRef<[u8]> + ?Sized), ) -> Option<Message<'x>>

Parses a byte slice containing the RFC5322 raw message and returns a Message struct containing only the headers.